@@ -16,6 +16,7 @@ from pytest_html import extras
 report_path = None
 report_name = None
 
+
 @pytest.hookimpl(hookwrapper=True)
 def pytest_runtest_makereport(item, call):
     pytest_html = item.config.pluginmanager.getplugin("html")
@@ -39,7 +40,9 @@ def pytest_runtest_makereport(item, call):
                 f_name = item.funcargs['test_mobile_obj'].gif_file_name
         if f_name:
             relative_path = os.path.relpath(f_name)
-            extra.append(extras.image(relative_path, mime_type='image/gif', extension='gif'))
+            extra.append(pytest_html.extras.html(
+                f'<div class="image"><img src="{relative_path}"/></div>')
+            )
         report.extra = extra
 
 @pytest.fixture
@@ -144,7 +147,7 @@ def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package,
                                         remote_flag, device_flag, app_name, app_path, ud_id, org_id, signing_id,
                                         no_reset_flag, appium_version)
         # Setup Appium Server
-        test_mobile_obj.start_appium()
+        # test_mobile_obj.start_appium()        #Start appium 2 locally
         # # 3. Setup TestRail reporting
         # if testrail_flag.lower() == 'y':
         #     if test_run_id is None:
@@ -258,6 +261,10 @@ def cases(request, product, testID):
                        usecols=lambda x: 'Remark' not in x)
     df = df.fillna('')
     row = df.index[df['testID'] == testID].tolist()
+
+    if not row:
+        pytest.skip(f"TestID {testID} not found in the Excel file.")
+
     data = (df.loc[row[0]])
     return data
 
