@@ -1140,10 +1140,18 @@ class Base_Page(Borg, unittest.TestCase):
             self.exceptions.append("An exception occurred when scrolling down")
             return False
 
-    def scroll_to_top_by_js(self):
+    def scroll_to_top_by_js(self, wait_time=0.5):
         top = self.execute_javascript_with_return("window.pageYOffset")
         cmd = "window.scrollBy(0, -%s)" % top
         self.execute_javascript(cmd)
+        time.sleep(wait_time)
+
+    def scroll_to_bottom_by_js(self, wait_time=0.5):
+        """Expect the HTML body scroll height only """
+        scrollHeight = self.execute_javascript_with_return("document.body.scrollHeight")
+        cmd = "window.scrollBy(0, %s)" % scrollHeight
+        self.execute_javascript(cmd)
+        time.sleep(wait_time)
 
     def hover(self, locator, wait_seconds=0.5):
         "Hover over the element"
@@ -1372,10 +1380,11 @@ class Base_Page(Borg, unittest.TestCase):
     def set_maximize_window(self):
         self.driver.maximize_window()
 
-    def scroll_by_amount(self, locator, delta_x: int, delta_y: int):
+    def scroll_by_amount(self, locator, delta_x: int, delta_y: int, wait_time=1):
         try:
             element = self.get_element(locator)
             element.scroll_by_amount(delta_x, delta_y)
+            time.sleep(wait_time)
         except Exception as e:
             self.write(str(e), 'debug')
             self.exceptions.append("An exception occurred when scroll by amount")
@@ -1398,12 +1407,12 @@ class Base_Page(Borg, unittest.TestCase):
         self.execute_javascript(cmd)
         self.wait(wait_time)
 
-    def scroll_to_dom_element_by_js(self, locator, wait_time=1):
+    def scroll_to_element_by_js(self, locator, wait_time=1):
         """If locator have multiple elements, will scroll to 1st element
         Assume window inner height is larger than element height
         Will screen down until the element display in the middle of windows
         Default Wait 1 second after calling js.
         ***Please be careful next operation will be executed while scrolling"""
-        self.scroll_to_dom_element_by_js(self.get_element(locator))
+        self.scroll_to_dom_element_by_js(self.get_element(locator), wait_time)
 
     # _get_locator = staticmethod(_get_locator) "COMMENT BECAUSE _get_locator commented"
